@@ -1,5 +1,6 @@
-"xpaint*helpFile:  /usr/local/share/xpaint/help/Help",
-"xpaint*msgFile:  /usr/local/share/xpaint/messages/Messages",
+"xpaint*helpFile:  help/Help",
+"xpaint*msgFile:  messages/Messages",
+"xpaint*shareDir: /usr/local/share/xpaint",
 "xpaint*fullpopup: False",
 "xpaint*paint.undoSize:		1",
 "*vertical*shadowWidth:          1",
@@ -554,7 +555,7 @@
 "*colorEditDialog.title:		XPaint / Color Selector",
 "xpaint*helpDialog.title:		XPaint / Help Browser",
 "xpaint*helpDialog.iconName:		XPaint Help",
-"xpaint*helpDialog.form.title.label:	XPaint 2.7.7 Help & Information",
+"xpaint*helpDialog.form.title.label:	XPaint 2.7.8.1 Help & Information",
 "xpaint*helpDialog*textTitle.width:	400",
 "xpaint*helpDialog*textText.width:	400",
 "xpaint*helpDialog*textText.height:	356",
